@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Distribution;
 # ABSTRACT: A Distribution data object
-$MetaCPAN::Client::Distribution::VERSION = '2.000000';
+$MetaCPAN::Client::Distribution::VERSION = '2.001000';
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -39,6 +39,9 @@ foreach my $field ( @known_fields ) {
 
 sub _known_fields { return \%known_fields }
 
+sub rt     { $_[0]->bugs->{rt}     || {} }
+sub github { $_[0]->bugs->{github} || {} }
+
 1;
 
 __END__
@@ -53,7 +56,7 @@ MetaCPAN::Client::Distribution - A Distribution data object
 
 =head1 VERSION
 
-version 2.000000
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -75,6 +78,16 @@ Hash-Ref.
 
 Hash-Ref.
 
+=head1 METHODS
+
+=head2 rt
+
+Returns 'bugs.rt' hash ref (defaults to {}).
+
+=head2 github
+
+Returns 'bugs.github' hash ref (defaults to {}).
+
 =head1 AUTHORS
 
 =over 4
