@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '2.000000';
+$MetaCPAN::Client::ResultSet::VERSION = '2.001000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref >;
@@ -32,7 +32,7 @@ has scroller => (
 has items => (
     is  => 'ro',
     isa => sub {
-        ref $_[0] eq 'ARRAY'
+        is_arrayref($_[0])
             or croak 'items must be an array ref';
     },
 );
@@ -91,7 +91,7 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 2.000000
+version 2.001000
 
 =head1 DESCRIPTION
 
